package com.vendor.burn.model.devices.unknown;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.vendor.burn.model.FileSystem;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IFileSystemSetting;
import com.vendor.burn.model.devices.unknown.UDProperties;
import com.vendor.burn.utilitily.ToolUtils;
import java.util.ArrayList;

public class UDFileSystemSetting implements IFileSystemSetting {
  FileSystem[] fileSystemsForPartitionBurner;
  
  FileSystem[] fileSystemsForEmmcBurner;
  
  FileSystem[] fileSystemsForMerge;
  
  FileSystem[] fileSystemsForCommonBurner;
  
  FileSystem[] fileSystemsForCmdLine;
  
  public static com.vendor.burn.model.devices.unknown.UDFileSystemSetting build(UDProperties properties) {
    com.vendor.burn.model.devices.unknown.UDFileSystemSetting fileSystemSetting = new com.vendor.burn.model.devices.unknown.UDFileSystemSetting();
    if (fileSystemSetting.init(properties))
      return fileSystemSetting; 
    return null;
  }
  
  private boolean init(UDProperties properties) {
    if (properties == null)
      return false; 
    ArrayList<FileSystem> fsList = new ArrayList<>();
    fsList.add(FileSystem.none);
    Integer yaffsInt = properties.queryForInteger("YAFFS");
    if (yaffsInt != null && yaffsInt.intValue() == 1)
      fsList.add(FileSystem.yaffs); 
    Integer squashFsInt = properties.queryForInteger("SQUASHFS");
    if (squashFsInt != null && squashFsInt.intValue() == 1)
      fsList.add(FileSystem.squashFs); 
    String boardType = properties.queryForString("TYPE");
    if (boardType != null && (
      boardType.equals("STB") || boardType.equals("CAM")))
      fsList.add(FileSystem.ubiFs); 
    this.fileSystemsForPartitionBurner = new FileSystem[fsList.size()];
    fsList.toArray(this.fileSystemsForPartitionBurner);
    Integer extInt = properties.queryForInteger("EXT");
    if (extInt != null && extInt.intValue() == 1)
      fsList.add(FileSystem.ext3); 
    Integer fat32Int = properties.queryForInteger("FAT32");
    if (fat32Int != null && fat32Int.intValue() == 1)
      fsList.add(FileSystem.TAT32); 
    fsList.add(FileSystem.f2fs);
    fsList.add(FileSystem.erofs);
    this.fileSystemsForMerge = new FileSystem[fsList.size()];
    fsList.toArray(this.fileSystemsForMerge);
    if (ToolUtils.isCmdLine()) {
      this.fileSystemsForCmdLine = new FileSystem[fsList.size()];
      fsList.toArray(this.fileSystemsForCmdLine);
    } else {
      this.fileSystemsForCommonBurner = new FileSystem[fsList.size()];
      fsList.toArray(this.fileSystemsForCommonBurner);
    } 
    fsList.clear();
    fsList.add(FileSystem.none);
    if (extInt != null && extInt.intValue() == 1)
      fsList.add(FileSystem.ext3); 
    fsList.add(FileSystem.f2fs);
    fsList.add(FileSystem.erofs);
    if (squashFsInt != null && squashFsInt.intValue() == 1)
      fsList.add(FileSystem.squashFs); 
    this.fileSystemsForEmmcBurner = new FileSystem[fsList.size()];
    fsList.toArray(this.fileSystemsForEmmcBurner);
    return true;
  }
  
  public FileSystem[] getFileSystems(IBurner burner) {
    if (ToolUtils.isCmdLine())
      return getFileSystemsForCmdLine(); 
    if (burner instanceof com.vendor.burn.model.devices.ICommonBurner)
      return getFileSystemsForCommonBurner(); 
    if (burner instanceof com.vendor.burn.model.devices.IEmmcBurner)
      return getFileSystemsForEmmcBurner(); 
    if (burner instanceof com.vendor.burn.model.devices.IMergeBurner)
      return getFileSystemsForMerge(); 
    if (burner instanceof com.vendor.burn.model.devices.IPartitionBurner)
      return getFileSystemsForPartitionBurner(); 
    return FileSystem.values();
  }
  
  public String[] getFileSystemNames(IBurner burner) {
    FileSystem[] fileSystems = getFileSystems(burner);
    String[] result = new String[fileSystems.length];
    for (int i = 0; i < result.length; i++)
      result[i] = fileSystems[i].name(); 
    return result;
  }
  
  public FileSystem findFileSystem(String name) {
    FileSystem[] values = FileSystem.values();
    for (FileSystem fileSystem : values) {
      if (fileSystem.name().equalsIgnoreCase(name))
        return fileSystem; 
    } 
    return null;
  }
  
  public FileSystem findFileSystem(IBurner burner, String name) {
    FileSystem[] values = getFileSystems(burner);
    for (FileSystem fileSystem : values) {
      if (fileSystem.name().equalsIgnoreCase(name))
        return fileSystem; 
    } 
    return null;
  }
  
  public FileSystem[] getFileSystemsForPartitionBurner() {
    return (FileSystem[])this.fileSystemsForPartitionBurner.clone();
  }
  
  public FileSystem[] getFileSystemsForEmmcBurner() {
    return (FileSystem[])this.fileSystemsForEmmcBurner.clone();
  }
  
  public FileSystem[] getFileSystemsForMerge() {
    return (FileSystem[])this.fileSystemsForMerge.clone();
  }
  
  public FileSystem[] getFileSystemsForCommonBurner() {
    return (FileSystem[])this.fileSystemsForCommonBurner.clone();
  }
  
  public FileSystem[] getFileSystemsForCmdLine() {
    return (FileSystem[])this.fileSystemsForCmdLine.clone();
  }
}
